==> bind-9.2.3rc2.tar.gz: bind-9.2.3rc2/bin/win32/BINDInstall/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by BINDInstall.rc
//
#define IDS_MAINFRAME                   1
#define IDS_CREATEDIR                   2
#define IDS_SUCCESS                     3
#define IDS_FAIL                        4
#define IDS_DIREXIST                    5
#define IDS_INSTALL_DIR                 6
#define IDS_INSTALL_FILE                7
#define IDS_INSTALL_SERVICE             8
#define IDS_INSTALL_MESSAGE             9
#define IDS_UNINSTALL                   14
#define IDS_UNINSTALL_DONE              15
#define IDS_CREATE_KEY                  16
#define IDS_ADD_REMOVE                  17
#define IDS_CLEANUP                     18
#define IDS_INSTALL_DONE                19
#define IDS_CREATE_DIR                  20
#define IDS_REMOVE_DIR                  21
#define IDS_COPY_FILE                   22
#define IDS_DELETE_FILE                 23
#define IDS_OPEN_SCM                    24
#define IDS_CREATE_SERVICE              25
#define IDS_OPEN_SERVICE                26
#define IDS_REMOVE_SERVICE              27
#define IDS_REGISTER_MESSAGES           28
#define IDS_UNREGISTER_MESSAGES         29
#define IDS_STOP_SERVICE                30
#define IDS_START_SERVICE               31
#define IDS_UNINSTALL_DIR               32
#define IDS_UNINSTALL_FILES             33
#define IDS_UNINSTALL_SERVICE           34
#define IDS_UNINSTALL_MESSAGE           35
#define IDS_ERR_OPEN_SCM                36
#define IDS_ERR_OPEN_SERVICE            37
#define IDS_ERR_STOP_SERVICE            38
#define IDS_ERR_NONCRIT_FILE            39
#define IDS_ERR_CRITICAL_FILE           40
#define IDS_ERR_COPY_FILE               40
#define IDS_ERR_CREATE_SERVICE          41
#define IDS_ERR_REMOVE_SERVICE          42
#define IDS_REBOOT                      43
#define IDS_BAD_PRIVILEGES              44
#define IDS_ERR_CREATE_DIR              45
#define IDS_VERSION                     46
#define IDS_ERR_CREATE_KEY              47
#define IDS_ERR_SET_VALUE               48
#define IDS_NO_VERSION                  49
#define IDS_EXISTING_NEWER              50
#define IDS_FILE_BAD                    51
#define IDD_BINDINSTALL_DIALOG          102
#define IDR_MAINFRAME                   128
#define IDD_BROWSE                      129
#define IDI_CHECK                       130
#define IDI_X                           132
#define IDC_TARGETDIR                   1001
#define IDC_BROWSE                      1002
#define IDC_DIRLIST                     1004
#define IDC_CURDIR                      1005
#define IDC_INSTALL                     1006
#define IDC_COPY_FILE                   1007
#define IDC_REG_SERVICE                 1008
#define IDC_REG_MESSAGE                 1009
#define IDC_CREATE_DIR                  1010
#define IDC_EXIT                        1011
#define IDC_DIR_TAG                     1012
#define IDC_COPY_TAG                    1013
#define IDC_SERVICE_TAG                 1014
#define IDC_MESSAGE_TAG                 1015
#define IDC_AUTO_START                  1016
#define IDC_UNINSTALL                   1017
#define IDC_VERSION                     1018
#define IDC_KEEP_FILES                  1019
#define IDC_CURRENT_TAG                 1020
#define IDC_DRIVES                      1021
#define IDC_CURRENT                     1021
#define IDC_START                       1022

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        142
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1027
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> bind-9.4.2rc1.tar.gz: bind-9.4.2rc1/bin/win32/BINDInstall/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by BINDInstall.rc
//
#define IDS_MAINFRAME                   1
#define IDS_CREATEDIR                   2
#define IDS_SUCCESS                     3
#define IDS_FAIL                        4
#define IDS_DIREXIST                    5
#define IDS_INSTALL_DIR                 6
#define IDS_INSTALL_FILE                7
#define IDS_INSTALL_SERVICE             8
#define IDS_INSTALL_MESSAGE             9
#define IDS_UNINSTALL                   14
#define IDS_UNINSTALL_DONE              15
#define IDS_CREATE_KEY                  16
#define IDS_ADD_REMOVE                  17
#define IDS_CLEANUP                     18
#define IDS_INSTALL_DONE                19
#define IDS_CREATE_DIR                  20
#define IDS_REMOVE_DIR                  21
#define IDS_COPY_FILE                   22
#define IDS_DELETE_FILE                 23
#define IDS_OPEN_SCM                    24
#define IDS_CREATE_SERVICE              25
#define IDS_OPEN_SERVICE                26
#define IDS_REMOVE_SERVICE              27
#define IDS_REGISTER_MESSAGES           28
#define IDS_UNREGISTER_MESSAGES         29
#define IDS_STOP_SERVICE                30
#define IDS_START_SERVICE               31
#define IDS_UNINSTALL_DIR               32
#define IDS_UNINSTALL_FILES             33
#define IDS_UNINSTALL_SERVICE           34
#define IDS_UNINSTALL_MESSAGE           35
#define IDS_ERR_OPEN_SCM                36
#define IDS_ERR_OPEN_SERVICE            37
#define IDS_ERR_STOP_SERVICE            38
#define IDS_ERR_NONCRIT_FILE            39
#define IDS_ERR_CRITICAL_FILE           40
#define IDS_ERR_COPY_FILE               40
#define IDS_ERR_CREATE_SERVICE          41
#define IDS_ERR_REMOVE_SERVICE          42
#define IDS_REBOOT                      43
#define IDS_BAD_PRIVILEGES              44
#define IDS_ERR_CREATE_DIR              45
#define IDS_VERSION                     46
#define IDS_ERR_CREATE_KEY              47
#define IDS_ERR_SET_VALUE               48
#define IDS_NO_VERSION                  49
#define IDS_EXISTING_NEWER              50
#define IDS_FILE_BAD                    51
#define IDS_ERR_TOOPRIVED               52
#define IDS_ERR_BADACCOUNT              53
#define IDS_ERR_WRONGPRIV               54
#define IDS_CREATEACCOUNT_FAILED        55
#define IDS_ERR_PASSWORD                56
#define IDS_ERR_UPDATE_SERVICE          57
#define IDS_ERR_NULLPASSWORD            58
#define IDS_ERR_WHITESPACE              59
#define IDD_BINDINSTALL_DIALOG          102
#define IDR_MAINFRAME                   128
#define IDD_BROWSE                      129
#define IDI_CHECK                       130
#define IDI_X                           132
#define IDC_CURSOR1                     142
#define IDD_DIALOG1                     143
#define IDC_TARGETDIR                   1001
#define IDC_BROWSE                      1002
#define IDC_DIRLIST                     1004
#define IDC_CURDIR                      1005
#define IDC_INSTALL                     1006
#define IDC_COPY_FILE                   1007
#define IDC_REG_SERVICE                 1008
#define IDC_REG_MESSAGE                 1009
#define IDC_CREATE_DIR                  1010
#define IDC_EXIT                        1011
#define IDC_DIR_TAG                     1012
#define IDC_COPY_TAG                    1013
#define IDC_SERVICE_TAG                 1014
#define IDC_MESSAGE_TAG                 1015
#define IDC_AUTO_START                  1016
#define IDC_UNINSTALL                   1017
#define IDC_VERSION                     1018
#define IDC_KEEP_FILES                  1019
#define IDC_CURRENT_TAG                 1020
#define IDC_DRIVES                      1021
#define IDC_CURRENT                     1021
#define IDC_START                       1022
#define IDC_ACCOUNT_NAME                1030
#define IDC_ACCOUNT_PASSWORD            1031
#define IDC_ACCOUNT_PASSWORD_CONFIRM    1032

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        144
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1027
#define _APS_NEXT_SYMED_VALUE           104
#endif
#endif
